@@ -35,7 +35,9 @@ from ._wrapped_ufuncs import *
 
 from .stability import *
 from .geostrophy import *
+from .utility import *
 from . import geostrophy
+from . import utility
 from . import stability
 from . import density
 from . import energy
@@ -45,4 +47,6 @@ from . import ice
 
 from .conversions import t90_from_t68
 
-__version__ = "3.1.1"
+from ._version import get_versions
+__version__ = get_versions()['version']
+del get_versions
